==> brevo_1_3.zip: plugins/sibactu/lang/sibactu_fr.php <==
<?php

/*******************************************************************************\
 * SIBACTU, plugin et squelette pour SPIP - https://www.spip.net/              *
 *         dédié à la gestion de mails via Sendinblue (Brevo)                  *
 *                                                                             *
 *         Copyright (C) 2023 Renaud LAURETTE                                  *
 *                                                                             *
\*******************************************************************************/

// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// Configuration	
	'titre_page_configurer_sibactu' => 'Configurer SibActu',
	'cfg_titre_sibactu' => 'Paramètres des lettres d\'actualité',
	'cfg_logoactu' => 'Logo de la lettre',
	'cfg_logoactu_explication' => 'URL absolue de l\'image',
	'cfg_sujet_explication' => 'Sujet par défaut',
	'cfg_tedito_explication' => 'Titre par défaut',
	'cfg_titre_explication' => 'Titre par défaut de la section',
	'cfg_les_modeles' => 'Liste des modèles de lettre',
	'cfg_les_modeles_explication' => 'Nom des pages, sans suffixe, séparés par des virgules',
	'cfg_propager_agenda' => 'Activer la propagation des événements de l\'agenda ?',
	'cfg_propager_agenda_explication' => 'Si la case est cochée, les événements seront notifiés aux membres des listes de diffusion d\'agenda.',	
	'cfg_sujet_agenda' => 'Titre de la lettre agenda',
	'cfg_sujet_agenda_explication' => 'Titre et sujet de la lettre envoyée pour notifier des prochains événements',	
	'cfg_listes_agenda' => 'Listes de diffusion des événements de l\'agenda',
	'cfg_listes_agenda_explication' => 'Identifiants Brevo, séparés par des virgules, sans espace.',	
	'cfg_modele_agenda' => 'Nom du modèle de la lettre',
	'cfg_modele_agenda_explication' => 'Ne pas indiquer le chemin ni l\'extension du fichier.',	
	'cfg_avance_agenda' => 'Nombre de jours d\'anticipation',
	'cfg_avance_agenda_explication' => 'Délai d\'anticipation des événements pour la notification',	
	'cfg_silence_agenda' => 'Nombre de jours de répit',
	'cfg_silence_agenda_explication' => 'Nombre minimum de jours de répit entre deux notifications',
	
	// Labels de Champs
	'sujet' => 'Sujet',
	'template' => 'Modèle de lettre',
	'editorial' => 'Editorial',
	'imgeditorial' =>'Image pour l\'éditorial',
	'lstobs' => 'Observations',
	'lstbrv' => 'Brèves',
	'lstcmp' => 'Campagnes',
	'lstart' => 'Articles',
	'lstesp' => 'Espèces',
	'lstlieu' => 'Lieux',
	
	// Titres des sections
	'teditorial' => 'Titre de l\'éditorial',
	'titreobs' => 'Titre pour les observations',
	'titrebrv' => 'Titre pour les brèves',
	'titrecmp' => 'Titre pour les campagnes',
	'titreart' => 'Titre pour les articles',
	'titreesp' => 'Titre pour les espèces',
	'titrelieu' => 'Titres pour les lieux',
	
	// explications de champs
	'quid_sujet' => 'de la lettre et du mail',
	'quid_template' => 'pour la composition du courriel',
	'quid_teditorial' => ' ',
	'quid_imgeditorial' => 'horizontale entre 620 et 1024px (URL complète)',
	'quid_editorial' => 'Texte long en syntaxe SPIP',
	'quid_liste' => 'Ids séparés par des virgules',
	'quid_titre' => ' ',
	
	// Valeurs par défaut
	'def_sujet' => 'Lettre d\'actualités',
	'def_tedito' => 'Une réflexion à partager',
	'def_tobs' => 'Observations remarquables',
	'def_tbrv' => 'Actualités en bref',
	'def_tcmp' => 'Participez aux campagnes d\'observation',
	'def_tart' => 'Comprendre et connaître',
	'def_tesp' => 'Des espèces à découvrir',
	'def_tlieu' => 'Nos milieux',
	
	
	// E
	'err_contenu_vide' => 'Contenu vide ou titres manquants',
	
	// O
	'ok_composition' => 'Composition effectuée',
	
	// P
	'page_actualite' => 'Afficher la page d\'actualités',	
	
);

==> brevo_1_4.zip: plugins/sibactu/lang/sibactu_fr.php <==
<?php

/*******************************************************************************\
 *         SIBACTU, plugin pour SPIP - https://www.spip.net/                   *
 *         dédié à la composition et l'envoi de lettres d'actualité            *
 *		   via Brevo (Sendinblue) et le plugin SIBMAIL                         *
 *                                                                             *
 *         Copyright (C) 2023-2025 Renaud LAURETTE                             *
 *                                                                             *
\*******************************************************************************/

// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// Configuration	
	'titre_page_configurer_sibactu' => 'Configurer SibActu',
	'cfg_titre_sibactu' => 'Paramètres des lettres d\'actualité',
	'cfg_logoactu' => 'Logo de la lettre',
	'cfg_logoactu_explication' => 'URL absolue de l\'image',
	'cfg_sujet_explication' => 'Sujet par défaut',
	'cfg_tedito_explication' => 'Titre par défaut',
	'cfg_titre_explication' => 'Titre par défaut de la section',
	'cfg_les_modeles' => 'Liste des modèles de lettre',
	'cfg_les_modeles_explication' => 'Nom des pages, sans suffixe, séparés par des virgules',
	'cfg_propager_agenda' => 'Activer la propagation des événements de l\'agenda ?',
	'cfg_propager_agenda_explication' => 'Si la case est cochée, les événements seront notifiés aux membres des listes de diffusion d\'agenda.',	
	'cfg_sujet_agenda' => 'Titre de la lettre agenda',
	'cfg_sujet_agenda_explication' => 'Titre et sujet de la lettre envoyée pour notifier des prochains événements',	
	'cfg_listes_agenda' => 'Listes de diffusion des événements de l\'agenda',
	'cfg_listes_agenda_explication' => 'Identifiants Brevo, séparés par des virgules, sans espace.',	
	'cfg_modele_agenda' => 'Nom du modèle de la lettre',
	'cfg_modele_agenda_explication' => 'Ne pas indiquer le chemin ni l\'extension du fichier.',	
	'cfg_avance_agenda' => 'Nombre de jours d\'anticipation',
	'cfg_avance_agenda_explication' => 'Délai d\'anticipation des événements pour la notification',	
	'cfg_silence_agenda' => 'Nombre de jours de répit',
	'cfg_silence_agenda_explication' => 'Nombre minimum de jours de répit entre deux notifications',
	'cfg_liste_templates_actualites' => 'Liste des templates',
	'cfg_liste_templates_actualites_explication' => 'Emplacement du fichier contenant la liste des templates à utiliser pour présenter les lettres d\'actualités',
	
	// Labels de Champs
	'sujet' => 'Sujet du courriel et de la lettre',
	'template' => 'Modèle de lettre',
	'editorial' => 'Editorial',
	'imgeditorial' =>'Image pour l\'éditorial',
	'lstbrv' => 'Brèves',
	'lstart' => 'Articles',

	
	// Titres des sections
	'teditorial' => 'Titre de l\'éditorial',
	'titrebrv' => 'Titre pour les brèves',
	'titreart' => 'Titre pour les articles',
	
	// explications de champs
	'quid_sujet' => 'de la lettre et du mail',
	'quid_template' => 'pour la composition du courriel',
	'quid_teditorial' => ' ',
	'quid_imgeditorial' => 'horizontale entre 620 et 1024px (URL complète)',
	'quid_editorial' => 'Texte long en syntaxe SPIP',
	'quid_liste' => 'Ids séparés par des virgules',
	'quid_titre' => ' ',
		
	// E
	'err_contenu_vide' => 'Contenu vide ou titres manquants',
	
	// O
	'ok_composition' => 'Composition effectuée',
	
	// P
	'page_actualite' => 'Afficher la page d\'actualités',	
	
);
